@@ -5,7 +5,7 @@ Weasel::Session - Connection to an encapsulated test driver
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 SYNOPSIS
 
@@ -50,7 +50,7 @@ use Module::Runtime qw/ use_module /;;
 use Weasel::FindExpanders qw/ expand_finder_pattern /;
 use Weasel::WidgetHandlers qw| best_match_handler_class |;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 =head1 ATTRIBUTES
@@ -490,12 +490,12 @@ sub _logged {
     $hook->("pre_$e", $pre);
     if (wantarray) {
         my @rv = $f->();
-        $hook->("post_$e", sub { return $l->(\@rv); });
+        $hook->("post_$e", sub { return $post->(\@rv); });
         return @rv;
     }
     else {
         my $rv = $f->();
-        $hook->("post_$e", sub { return $l->($rv); });
+        $hook->("post_$e", sub { return $post->($rv); });
         return $rv;
     }
 };
